---
id: stitch-frames-to-video
title: stitchFramesToVideo()
---

_Part of the `@remotion/renderer` package._

Takes a series of images and audio information generated by [`renderFrames()`](/docs/render-frames) and encodes it to a video.

```ts
const stitchFramesToVideo: (options: {
  dir: string
  fps: number
  width: number
  height: number
  outputLocation: string
  force: boolean
  assetsInfo: RenderAssetInfo
  imageFormat?: 'png' | 'jpeg' | 'none'
  pixelFormat?: PixelFormat
  codec?: Codec
  crf?: number
  onProgress?: (progress: number) => void
  onDownload?: (src: number) => void
  verbose?: boolean
}) => Promise<void>
```

## Arguments

An object with the following properties:

### `dir`

A `string` containing the absolute path of the directory where the frames are located. This will be the directory where the `ffmepg` command will be executed.

### `fps`

A `number` specifying the desired frame rate of the output video.

### `width`

A `number` specifying the desired output width in pixels for the video.

### `height`

A `number` specifying the desired output height in pixels for the video.

### `outputLocation`

An absolute path specify where the output file should be written to.

### `force`

Whether in case of an existing file in `outputLocation` it should be overwritten. Type `boolean`.

### `assetsInfo`

Information about the audio mix. This is part of the return value of [renderFrames()](/docs/render-frames#return-value).

### `imageFormat?`

_optional_

Either `jpeg`, `png` or `none`. It should match what you passed into the [renderFrames()](/docs/render-frames#imageformat) function.

:::info
For backwards compatibility, if you omit this parameter, it will use `'png'`. Make sure to explicitly set this to `jpeg` to take advantage of faster rendering.
:::

### `pixelFormat?`

_optional_

Sets the pixel format. See [here](/docs/config#setpixelformat) for available values. The default is `yuv420p`.

### `codec?`

_optional_

Set a codec. See the [encoding guide](/docs/encoding) for available values and guidance on which one to choose. The default is `h264`.

### `crf?`

_optional_

The constant rate factor of the output, a parameter which controls quality. See [here](/docs/config#setcrf) for more information about this parameter. Default is depending on the codec.

### `onProgress?`

_optional_

Callback function which informs about the encoding progress. The `progress` value is a `number` between 0 and 1.

```ts twoslash
const onProgress = (progress: number) => {
  console.log(`Encoding progress: ${progress * 100}%`)
}
```

### `onDownload?`

_optional_

Notifies when a remote asset needs to be downloaded in order to extract the audio track.

```ts twoslash
const onDownload = (src: string) => {
  console.log(`Downloading ${src}...`)
}
```

### `verbose`

A boolean value that when set to `true`, will log all kinds of debug information. Default `false`

## Return value

`stitchFramesToVideo()` returns a promise which resolves to nothing. If everything goes well, the output will be placed in `outputLocation`.

## See also

- [bundle()](/docs/bundle)
- [Server-Side rendering](/docs/ssr)
- [getCompositions()](/docs/get-compositions)
- [renderFrames()](/docs/render-frames)
